@@ -8,8 +8,6 @@ from crossref.restful import Etiquette, Works
 from django.db.models import QuerySet
 
 from lxml import etree as ET
-import xmltodict
-from rich.progress import track
 
 
 def show_preservation(container_title: str, issn: str, volume: str,
